==> owlapi-api-4.2.5-sources.jar: org/semanticweb/owlapi/formats/AbstractRDFPrefixDocumentFormat.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.formats;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.io.RDFParserMetaData;
import org.semanticweb.owlapi.io.RDFResourceParseError;

/**
 * An Abstract Document Format for Prefix aware RDF formats. Renamed from
 * AbstractDFDocumentFormat
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 * @author Simon Spero
 * @since 4.0.1
 */
public abstract class AbstractRDFPrefixDocumentFormat extends
        PrefixDocumentFormatImpl implements RDFDocumentFormat {

    private static final long serialVersionUID = 40000L;
    // TODO make something of these
    private final Set<RDFResourceParseError> errors = new HashSet<>();

    @Override
    public RDFParserMetaData getOntologyLoaderMetaData() {
        return (RDFParserMetaData) super.getOntologyLoaderMetaData();
    }

    @Override
    public void addError(RDFResourceParseError error) {
        errors.add(error);
    }
}

==> owlapi-api-5.0.5-sources.jar: org/semanticweb/owlapi/formats/AbstractRDFPrefixDocumentFormat.java <==
/* This file is part of the OWL API.
 * The contents of this file are subject to the LGPL License, Version 3.0.
 * Copyright 2014, The University of Manchester
 * 
 * This program is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License along with this program.  If not, see http://www.gnu.org/licenses/.
 *
 * Alternatively, the contents of this file may be used under the terms of the Apache License, Version 2.0 in which case, the provisions of the Apache License Version 2.0 are applicable instead of those above.
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License. */
package org.semanticweb.owlapi.formats;

import java.util.HashSet;
import java.util.Set;

import org.semanticweb.owlapi.io.RDFResourceParseError;

/**
 * An Abstract Document Format for Prefix aware RDF formats. Renamed from
 * AbstractDFDocumentFormat
 * 
 * @author Matthew Horridge, The University of Manchester, Information
 *         Management Group
 * @since 3.0.0
 * @author Simon Spero
 * @since 4.0.1
 */
public abstract class AbstractRDFPrefixDocumentFormat extends PrefixDocumentFormatImpl implements RDFDocumentFormat {

    // TODO make something of these
    private final Set<RDFResourceParseError> errors = new HashSet<>();

    @Override
    public void addError(RDFResourceParseError error) {
        errors.add(error);
    }
}
